# USER SETTINGS SCRIPT FOR SENDING PUSHOVER/TELEGRAM NOTIFICATIONS WITH A GIF FILE ATTACHMENT
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'bi_gif_tool.ps1'
#   2. This script must be located in the same folder as script 'bi_gif_tool.ps1'
#   3. This script is suitable for 'BI_gif_tool.ps1' versions V3+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# ENTER THIS APP'S FOLDER LOCATION
	# ... [string] like, "D:\BI_gif_tool"
	# ... This will be the root folder for CSV, GIF, and JPG files created by this script
	$app_path = "YOUR_APP_FOLDER_PATH"

	# ENTER NON-DEFAULT BLUE IRIS BVR FOLDER PATHS (OTHER LOCATIONS THAN FOLDER 'NEW')
	# ... [list] comma-delimited, like 'D:\BlueIris\Aux1','J:\BlueIris\New' (default is "")
	# ... KEY POINT: No entry is required if your Blue Iris system is USING ONLY THE DEFAULT Blue Iris 'New' folder
	#     If you leave this setting as blank '' (or the line commented out), then the 'New' folder path is obtained 
	#     via the Windows registry
	# ... KEY POINTS: 
	#     1. This setting is REQUIRED ONLY if your Blue Iris system is configured to use multiple 'New' folders;
	#        that is, if you have one or more cameras recording video to BI Storage folders BESIDES the default 
	#        'New' folder (e.g., 'Aux1') ... Check Camera settings > Record tab > Video Folder
	#     2. If you are using a network share for Blue Iris storage, note that the BI service may not understand
	#        your file system designations like 'H:' etc. as these are user-specific. 
	#        Per the BI Help PDF, you should always use UNC names where possible (\\server\share).
	$bi_new_folder_paths = ""
	#$bi_new_folder_paths = "J:\BlueIris\New"
	#$bi_new_folder_paths = "D:\BlueIris\Aux1","J:\BlueIris\New"

	# OPT-IN TO USING CREDENTIALS WHEN USING BLUE IRIS HTTP INTERFACE COMMANDS
	# ... [boolean] expecting $true or $false (default is $false)
	# ... KEY-POINTS: 
	#     1. Sending the username and password with every URL increases the attack surface; it gives an attacker 
	#     more messages to find (and even if encrypted, more with constant data to try to decrypt).
	#     2. To avoid frequently passing your BI credentials in the clear, consider using an entry like "^192.168.1.*" 
	#     in Blue Iris Settings > 'Web server' > Advanced > 'Limit access by IP address'
	#     where "^192.168.1.*" is the local address of your Blue Iris Web Server.
	#     3. Per the BI Help PDF, the caret (^) prefix "allows this address to be used without authentication  
	#     USING THE ACCOUNT 'ADMIN'; THIS ACCOUNT MUST EXIST AND IT MUST BE ENABLED"
	#     4. Likewise for WAN access, consider using an entry like "^myusername.ipctddns.com".
	$post_w_creds_flg = $false
	#$post_w_creds_flg = $true

	# ENTER YOUR WEBSERVER'S USERNAME & PASSWORD CREDENTIALS
	# ... CREDENTIALS ARE REQUIRED TO ACCESS THE BLUE IRIS WEBSERVER VIA THE JSON INTERFACE
	# ... NOTE: ACCOUNT MUST BE ADMIN if setting $post_to_BI_logfile_flg (below) is $true
	# ... NOTE: to use credentials, be sure to uncheck 'Use secure session keys and login page' 
	#     in Blue Iris settings: click Settings > Web server > Advanced
	$bi_user_name = "YOUR_BI_USER_NAME"
	$bi_user_pw = "YOUR_BI_USER_PASSORD"

	# ENTER DEFAULT PUSH APPLICATION
	# ... [string] expecting "Pushover" or "Telegram" or "Pushover,Telegram", case-insensitive (default is 'Pushover")
	# ... NOTE: may be overridden using argument -PushMethod
	$push_service = "Pushover"
	#$push_service = "Telegram"
	#$push_service = "Pushover,Telegram"
	
	# IF USING PUSHOVER ...

		# ENTER YOUR PUSHOVER API USER KEY
		# ... https://pushover.net/
		$po_user_token = "YOUR_API_USER_KEY"

		# ENTER YOUR PUSHOVER API APPLICATION TOKEN
		# ... https://pushover.net/ (scroll down to 'Your Applications')
		# ... TIP: consider adding a 'PowerShell' application to your https://pushover.net/ account
		$po_app_token = "YOUR_API_APPLICATION_TOKEN"

	# IF USING TELEGRAM ...
	
		# Setting up: 
		# Use the following link to create a new Telegram Bot token and a Blue Iris 'channel' chat id.
		# (I named my channel 'Blueiris_xxx' ... xxx = my initials) 
		# http://www.marrold.co.uk/2017/04/push-notifications-from-tasker-to.html
		
		# Notification customization: 
		# Unlike Pushover, Telegram does not support server-side customization of notifications (only device-side). 
		# So customizations must be set up on your device:
		# 1. Open the Telegram app on your device after receiving a notification
		# 2. Tap the channel name > Notifications > Customize
		# 3. Customize the sound, vibration, repeat frequency, and priority
		# 4. Restart your device

		# ENTER YOUR TELEGRAM BOT API TOKEN
		# ... https://core.telegram.org/bots
		$tg_api_token = "YOUR_API_TOKEN"

		# ENTER YOUR TELEGRAM BOT CHAT ID
		# ... https://core.telegram.org/bots
		$tg_chat_id = "YOUR_CHAT_ID"
	
# OPTIONAL SETTINGS

	# SCRIPT OPTIONS

		# OPT-IN TO ALWAYS REQUIRING NEW SESSION KEYS FOR BLUE IRIS JSON COMMANDS
		# ... [boolean] expecting $true or $false (default is $false)
		# ... The script normally saves/reuses JSON command session keys to/from a disk file
		#     WHY? Reusing an active session key is typically 10X-100X faster than generating a new one
		#     (the location of the file is C:\temp\{scriptnsme}\bi_session_key_{host}.txt)
		# ... This setting is provided to override the default behavior; try it if the the script is not working
		$require_new_json_session_keys_flg = $false
		#$require_new_json_session_keys_flg = $true

		# OPT OUT OF CHECKS AND MESSAGING INTENDED TO HELP NEW USERS
		# ... [boolean] expecting $true or $false (default is $false)
		$experienced_user_flg = $false
		#$experienced_user_flg = $true

		# OPT-OUT OF BACKGROUND MESSAGING
		# ... [boolean] expecting $true or $false (default is $true)
		# ... Key Points: 
		#     1. Background messages are enabled only if script is running in the background
		#     2. This global setting may be overridden by argument '-Quiet'
		$bg_msgs_on = $true
		#$bg_msgs_on = $false

	# GIF FILE GLOBAL OPTIONS

		# ENTER GIF'S HEIGHT DIMENSION
		# ... [integer] units are pix (default is 320)
		# ... The aspect ratio is unchanged by resizing
		$gif_height = 320

		# ENTER GIF FRAMES PER SECOND
		# ... [integer] (default is 2)
		# ... Use a higher value to make the GIF play faster
		$gif_fps = 2

		# ENTER MAX LIFETIME FOR ARCHIVED GIF FILES
		# ... All GIF files created by this script are automatically archived to folder '$app_path\_gif_archive'
		# ... To prevent this folder from growing excessively large, this setting deletes GIF files after a given age
		#     (aka a 'pruning operation' that searches for backups older than a retention time)
		# ... TIP: Use 0 to disable monitoring of the archive folder
		# ... [integer] (default is 360 hours <== 15 days)
		$gif_archive_lifetime_hours = 360
		#$gif_archive_lifetime_hours = 0
		#$gif_archive_lifetime_hours = 720

	# SOURCING GIF FILES FROM BLUE IRIS 'DAT' FILES

		# ENTER REQUIRED NUMBER OF JPGs IN 'DAT' FILE
		# ... [integer] (default is 4)
		# ... Otherwise, the GIF will be created from the BLUE IRIS VIDEO CLIP (BVR)
		# ... TIP: setting a high value will force GIF creation from BVR clip
		$gif_DAT_reqd_images_cnt = 4
		#$gif_DAT_reqd_images_cnt = 6
		#$gif_DAT_reqd_images_cnt = 30

		# ENTER AGE MULTIPLIER FOR TEMPORARY 'DAT' FILES TO BE CONSIDERED 'FRESH'
		# ... [integer] default is 2
		# ... This setting applies only to temporary DAT files created in 'C:\ProgramData\Blue Iris\temp' (v5.9.9.29+)
		# ... The temporary DAT file will not be used if it is older than mult*alertmsec, where 'alertmsec'
		#     is obtained from the JSON alertlist parameter 'msec'
		# ... TIP: This default behavior can be overridden by using script argument -IgnnoreDatAge
		$dat_is_fresh_mult = 2
		#$dat_is_fresh_mult = 1

	# SOURCING GIF FILES FROM BLUE IRIS VIDEO CLIPS (BVRs)

		# TIP: set '$gif_DAT_reqd_images_cnt' to high value (next section) to force GIF creation from BVR clip

		# ENTER COUNT OF JPGS TO USE IN THE GIF ANIMATION
		# ... [integer] (default is 10)
		$gif_images_cnt = 10

		# OPT-OUT OF EXTRACTING JPGS FROM THE BVR SUB-STREAM BY DEFAULT
		# ... [boolean] expecting $true or $false (default is $true)
		# ... KEY POINTS: 
		#     1. Using the main-stream JPGs may result in longer GIF make times and slower notifications
		#     2. The as-extracted JPG size is displayed in the default notification text; if the next setting
		#        $jpg_images_match_gif_height_flg = $false, then the un-modified as-extracted JPG size is shown
		$jpg_images_from_substream_flg = $true
		#$jpg_images_from_substream_flg = $false

		# OPT-OUT OF EXTRACTING SMALLER JPGS FROM THE BVR FILE BY DEFAULT (MATCH THE GIF's HEIGHT)
		# ... [boolean] expecting $true or $false (default is $true)
		# ... KEY POINTS: 
		#     1. Using the default JPG size may result in longer GIF make times and slower notifications
		#     2. JPGs extracted from the BVR main-stream are substantially larger than from the sub-stream
		#     3. The as-extracted JPG size is displayed in the default notification text when NOT using argument -Msg
		$jpg_images_match_gif_height_flg = $true
		#$jpg_images_match_gif_height_flg = $false

		# ENTER PERCENTAGE OF ALERT CLIP TO ALWAYS TRIM FROM (OR ADD TO) THE LEFT SIDE FOR GIF ANIMATION
		# ... Use to remove or increase the portion of the Alert's duration shown in the GIF
		# ... [integer] expecting a +/- value (default is 0)
		# ... Positive values may be used with both DAT and BVR derived GIFs
		# ... Negative values may be used ONLY by BVR derived GIFs (JPGs will be collected BEFORE Alert's database offset)
		# ... Use cmdline argument -TrimBegPct to customize the trim percent for specific cameras
		# ... NOTE: The sum of $gif_trim_beg + $gif_trim_end (or gif_trim_end_cust) must be between 0 and 100
		$gif_trim_beg = 0

		# ENTER PERCENTAGE OF ALERT CLIP TO ALWAYS TRIM FROM RIGHT SIDE FOR GIF ANIMATION
		# ... Use to eliminate the right-side portion of the Alert's duration shown in the GIF
		# ... [integer] expecting a value >= 0 (default is 0)
		# ... Use cmdline argument -TrimEndPct to customize the trim percent for specific cameras
		# ... NOTE: The sum of $gif_trim_beg + $gif_trim_end (or gif_trim_end_cust) must be between 0 and 100
		$gif_trim_end = 0
		#$gif_trim_end = 40

		# CUSTOMIZE ALERT CLIP RIGHT TRIM BASED ON AI RESULTS
		# ... WHY? Faster moving objects may result in a GIF with just a couple of frames
		# ... expecting an object, like, @{ 'ai_label_1' = pct ; 'ai_label_1' = pct ; ... } 
		# ... [array] default is @{}
		# ... Use positive values for fast-moving objects (to use less of the clip)
		# ... Use negative values for slow/random-moving objects (to use more of the clip)
		# ... NOTE: The sum of $gif_trim_beg + gif_trim_end_cust must be between 0 and 100
		# ... NOTE: Activated by use of argument -AlertMemo '&MEMO'
		#		    (typically used in a Blue Iris Action Set 'Run-a-program' Action)
		$gif_trim_end_cust_obj = @{}
		<# $gif_trim_end_cust_obj = @{
			'vehicle' = 30  # Use fewer clips for fast moving objects
			'car' = 30
			'truck' = 20
			#'person' = 5
			#'dog' = -40  # Use the whole clip for slow/random moving objects
			#'cat' = -40 
		} #>

	# NOTIFICATION MESSAGE DEFAULTS (ALL PUSH SERVICES)

		# OPT OUT OF APPENDING GIF METHOD TAGS LIKE TO NOTIFICATIONS MESSAGES
		# ... These tags are like ' (viaDAT:n)' or ' (viaClip)' or ' (viaLiveStream)', where n is the number of JPGs found in the DAT file
		#     The number is MAXIMUM number of JPGs that may be used in to make the GIF file
		# ... [boolean] expecting $true or $false (default is $true)
		$append_gif_method_tag_flg = $true
		#$append_gif_method_tag_flg = $false

		# OPT OUT OF APPENDING SCRIPT PERFORMANCE (GIF MAKE TIME) TO NOTIFICATIONS MESSAGES
		# ... These tags are like 'GifMakeTime: 1234 msec'
		# ... [boolean] expecting $true or $false (default is $true)
		$append_performance_tag_flg = $true
		#$append_performance_tag_flg = $false

		# OPT IN TO APPENDING SCRIPT PERFORMANCE DETAILS TO NOTIFICATIONS MESSAGES
		# ... These tags are like '-DatImgExtractMsec: 409 msec'
		# ... [boolean] expecting $true or $false (default is $false)
		# ... NOTE: setting is ignored if setting$append_performance_tag_flg = $false
		$append_performance_tag_details_flg = $false
		#$append_performance_tag_details_flg = $true

	# PUSHOVER NOTIFICATION DEFAULTS

		# ENTER PUSHOVER MESSAGE PRIORITY
		# ... [integer] -2|-1|0|1|2 (default is 0); 2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency
		# ... see https://pushover.net/api#priority
		$po_priority = 2

		# ENTER PUSHOVER SOUND
		# ... [string] (default is "", the Pushover default sound)
		# ... see https://pushover.net/api#sounds
		$po_sound = ""  # default sound
		#$po_sound = "siren"  # built-in sound
		#$po_sound = "not-kiddin"  # custom sound

		# ENTER PUSHOVER DEVICE(S)
		# ... [string] (default is "", all Pushover devices)
		# ... may be comma-delimited list.
		# ... see https://pushover.net/api
		$po_device = ""  # all devices
		# $po_device = "galaxy-s24"  # single device
		# $po_device = "galaxy-s24,iPhoneXS"  # multiple devices

		# ENTER PUSHOVER RETRY PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... [integer] (default is 30)
		# ... see https://pushover.net/api#priority
		$po_retry = 30

		# ENTER PUSHOVER EXPIRE PARAMETER (SECONDS)
		# ... Required for priority=2 messages (emergency)
		# ... [integer] (default is 300)
		# ... see https://pushover.net/api#priority
		$po_expire = 300

		# ENTER PUSHOVER EMERGENCY PRIORITY 'TAGS'
		# ... [string] (default is "", default tag)
		# ... see https://pushover.net/api#priority
		$po_tags = ""
		#$po_tags = "a=BI,c=&CAM,g=Front"  # custom tags
		#$po_tags = "a=BI,c=&CAM"  # custom tags

	# LOGGING TO THE BLUE IRIS LOGFILE

		# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
		# ... [boolean] expecting $true or $false (default is $false)
		# ... NOTE: setting $bi_user_name (above) MUST BE ADMIN AND ENABLED
		$post_to_BI_logfile_flg = $false
		#$post_to_BI_logfile_flg = $true

		# OPT-OUT OF LOGGING ALL EVENTS (NOT JUST ERRORS)
		# ... [boolean] expecting $true or $false (default is $true)
		# ... NOTE: setting is ignored if setting $post_to_BI_logfile_flg = $false
		$post_all_events = $true
		#$post_all_events = $false

# END USER SETTINGS
# ===============================================
